@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996 Vectaport Inc.
+ * Copyright (c) 1996,1999 Vectaport Inc.
  *
  * Permission to use, copy, modify, distribute, and sell this software and
  * its documentation for any purpose is hereby granted without fee, provided
@@ -30,6 +30,7 @@
 
 #ifdef HAVE_ACE
 
+#include <signal.h>
 #include <ace/Acceptor.h>
 #include <ace/Reactor.h>
 #include <ace/Singleton.h>
@@ -38,6 +39,7 @@
 
 class ComTerpServ;
 
+//: handler to invoke ComTerp on socket (version with ACE)
 class ComterpHandler : public ACE_Svc_Handler<ACE_SOCK_STREAM, ACE_NULL_SYNCH>
 {
 
@@ -51,20 +53,34 @@ public:
 
   // = Hooks for opening and closing handlers.
   virtual int open (void *);
+  // open handler hook.
   virtual int close (u_long);
+  // close handler hook.
 
   const char* timeoutscript();
+  // return text of commands to execute every timeout.
   void timeoutscript(const char*);
+  // install new text of commands to execute every timeout.
   int timeoutscriptid();
+  // return symbol id of text of commands to execute every timeout.
   void timeoutscriptid(int);
+  // set symbol id of text of commands to execute every timeout.
+
+  void timeoutseconds(int seconds) { _seconds = seconds; }
+  // set timeout period in seconds.
+  int timeoutseconds() { return _seconds; }
+  // return timeout period in seconds.
 
   ComTerpServ* comterp() { return comterp_; }
+  // return associated ComTerpServ pointer.
 
 protected:
   // = Demultiplexing hooks.
   virtual int handle_input (ACE_HANDLE);
+  // called when input ready on ACE_HANDLE.
   virtual int handle_timeout (const ACE_Time_Value &tv, 
 			      const void *arg); 
+  // called when timer goes off.
 
   char peer_name_[MAXHOSTNAMELEN + 1];
   // Host we are connected to.
@@ -74,17 +90,20 @@ protected:
 
   int  _timeoutscriptid;
   // command for timeoutscript execution
+
+  int _seconds;
+  // timeout in seconds
 };
 
-// A Reactor Singleton.
+//: A Reactor Singleton.
 typedef ACE_Singleton<ACE_Reactor, ACE_Null_Mutex> 
 	COMTERP_REACTOR;
 
-// An ACE_Test_and_Set Singleton.
+//: An ACE_Test_and_Set Singleton.
 typedef ACE_Singleton<ACE_Test_and_Set <ACE_Null_Mutex, sig_atomic_t>, ACE_Null_Mutex> 
 	COMTERP_QUIT_HANDLER;
 
-// Specialize a ComterpAcceptor.
+//: Specialize a ComterpAcceptor.
 typedef ACE_Acceptor <ComterpHandler, ACE_SOCK_ACCEPTOR> 
 	ComterpAcceptor;
 
@@ -95,6 +114,7 @@ typedef ACE_Acceptor <ComterpHandler, ACE_SOCK_ACCEPTOR>
 
 class ComTerpServ;
 
+//: version without ACE
 class ComterpHandler {
 public:
     ComterpHandler(void) {comterp_ = new ComTerpServ(); _handle = 0;}
