@@ -38,6 +38,7 @@ History:        Written by Scott E. Johnston, March 1989
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
+#include <unistd.h>
 
 #include "comutil.ci"
 
@@ -79,7 +80,7 @@ Summary:
 #include <ComUtil/comutil.h>
 */
 
-int err_open( errfile )
+int err_open(char * errfile )
 
 
 /*!
@@ -91,7 +92,9 @@ Parameters:
 
 Type            Name          IO  Description
 ------------    -----------   --  -----------                  */
+#ifdef DOC
 char *          errfile   ;/* I   Filename of error file. */
+#endif
 
 
 /*!
@@ -126,7 +129,7 @@ See Also:  err_read, err_set, err_get, err_print, err_str, err_clear,
 	if( ErrorStreams[findex] == NULL ) 
 	    break;
     if( findex == MAX_ERROR_OPENS )
-	KAPUT1( "Exceeded maximum number of opened error files", 
+	KAPUT1( "Exceeded maximum number of opened error files (%d)", 
 		MAX_ERROR_OPENS );
     
     /* Attempt to open error file */
@@ -172,7 +175,7 @@ Summary:
 #include <ComUtil/comutil.h>
 */
 
-char * err_read( errid, errnum )
+char * err_read(int errid,unsigned errnum)
 
 
 /*!
@@ -184,8 +187,10 @@ Parameters:
 
 Type            Name          IO  Description
 ------------    -----------   --  -----------                  */
+#ifdef DOC
 int             errid     ;/* I   Identifier generated by `err_open`. */
 unsigned        errnum    ;/* I   Number of format string to search for. */
+#endif
 
 
 /*!
@@ -232,7 +237,7 @@ Summary:
 #include <ComUtil/comutil.h>
 */
 
-void err_set( errid, errnum, errlen )
+void err_set(int errid,unsigned errnum,unsigned errlen)
 
 
 /*!
@@ -243,11 +248,13 @@ Parameters:
 
 Type            Name          IO  Description
 ------------    -----------   --  -----------                  */
+#ifdef DOC
 int             errid     ;/* I   Identifier generated by `err_open`. */
 unsigned        errnum    ;/* I   Error number */
 unsigned        errlen    ;/* I   Length of error message string just
 				  printed by `fprintf` to file pointer
 				  returned from `err_fileio`. */
+#endif
 
 
 /*!
@@ -299,7 +306,7 @@ Summary:
 #include <ComUtil/comutil.h>
 */
 
-void err_get( errid, errnum )
+void err_get(int * errid,unsigned * errnum )
 
 
 /*!
@@ -310,9 +317,11 @@ Parameters:
 
 Type            Name          IO  Description
 ------------    -----------   --  -----------                  */
+#ifdef DOC
 int *           errid     ;/* I   Identifier generated by `err_open`. */
 unsigned *      errnum    ;/* I   Positive error number, that should
 				  have a unique association with `errid`. */
+#endif
 
 
 /*!
@@ -355,7 +364,7 @@ Summary:
 #include <ComUtil/comutil.h>
 */
 
-void err_print( outstream, command )
+void err_print(FILE * outstream,char * command)
 
 
 /*!
@@ -366,8 +375,10 @@ Parameters:
 
 Type            Name          IO  Description
 ------------    -----------   --  -----------                  */
+#ifdef DOC
 FILE *          outstream ;/* I   File pointer for output of errors.  */
 char *          command   ;/* I   Name of command where error occurred */
+#endif
 
 
 /*!
@@ -460,7 +471,7 @@ Summary:
 #include <ComUtil/comutil.h>
 */
 
-void err_str( errbuf, bufsiz, command )
+void err_str(char * errbuf,int bufsiz,char * command)
 
 
 /*!
@@ -471,9 +482,11 @@ Parameters:
 
 Type            Name          IO  Description
 ------------    -----------   --  -----------                  */
+#ifdef DOC
 char *		errbuf    ;/* O   Buffer to store formated error string */  
 int		bufsiz	  ;/* I   size of errbuf */
 char *          command   ;/* I   Name of command where error occurred */
+#endif
 
 
 /*!
@@ -620,7 +633,7 @@ Summary:
 #include <ComUtil/comutil.h>
 */
 
-void err_level( level )
+void err_level(unsigned level)
 
 
 /*!
@@ -631,7 +644,9 @@ Parameters:
 
 Type            Name          IO  Description
 ------------    -----------   --  -----------                  */
+#ifdef DOC
 unsigned        level     ;/* I   USER_LEVEL or PROG_LEVEL */
+#endif
 
 
 /*!
