@@ -177,7 +177,9 @@ void GFieldEditor::make_body() {
     label_->append(lk.hspace(2));
     int bar1 = Math::min(point_pos_, mark_pos_);
     int bar2 = Math::max(point_pos_, mark_pos_);
+#if 0
     if (!cursor_is_on_) bar1 = bar2;
+#endif
     int i = 0;
     Display* d = Session::instance()->default_display();
     for (; i < bar1; i++) {
@@ -278,7 +280,8 @@ void GFieldEditor::insert_char(char ch) {
     const Allocation& a = allocation();
     WidgetKit& wk = *WidgetKit::instance();
     float swidth = wk.font()->width(field_->Text(), field_->Length());
-    float cwidth = wk.font()->width(&ch, 1);
+    char cbuf[] = { ch, '\0' };
+    float cwidth = wk.font()->width((char*) cbuf, 1);
     float fwidth = a.right() - a.left() - _frame_thickness*2;
     if (swidth + cwidth > fwidth ) {
 	cerr << "\007";
@@ -299,6 +302,12 @@ void GFieldEditor::clear_buffer() {
     update();
 }
 
+void GFieldEditor::select_all() { 
+    mark_pos_ = 0;
+    point_pos_ = field_->characters();
+    update();
+}
+
 GFieldEditorAction::GFieldEditorAction() { }
 GFieldEditorAction::~GFieldEditorAction() { }
 void GFieldEditorAction::accept(GFieldEditor*) { }
