@@ -740,13 +740,13 @@ boolean OvNewViewCmd::IsA (ClassId id) {
 OvNewViewCmd::OvNewViewCmd (ControlInfo* c, const char* display) 
 : NewViewCmd(c) 
 { 
-  _display = strdup(display); 
+  _display = display ? strdup(display) : nil; 
 }
 
 OvNewViewCmd::OvNewViewCmd (Editor* ed, const char* display) 
 : NewViewCmd(ed) 
 { 
-  _display = strdup(display);
+  _display = display ?  strdup(display) : nil;
 }
 
 OvNewViewCmd::~OvNewViewCmd() { 
@@ -792,7 +792,8 @@ void OvNewViewCmd::set_display() {
 
 const char* OvNewViewCmd::display() { return _display; }
 void OvNewViewCmd::display(const char* display ) 
-{ delete _display; _display = strdup(display); }
+{ delete _display; 
+  _display = display ? strdup(display) : nil; }
 
 implementActionCallback(OvNewViewCmd)
 
@@ -1055,7 +1056,7 @@ void OvWindowDumpAsCmd::Execute () {
     Editor* ed = GetEditor();
 
     char buf[CHARBUFSIZE];
-    sprintf(buf, "Dump this window as:");
+    sprintf(buf, "Dump canvas in .xwd format to:");
 
     boolean reset_caption = false;
     Style* style = new Style(Session::instance()->style());
@@ -1095,7 +1096,7 @@ void OvWindowDumpAsCmd::Execute () {
 		style->attribute("caption", "Couldn't save to file!" );
             } else {
 	      char cmdbuf[CHARBUFSIZE];
-	      sprintf(cmdbuf, "xwd -id %d -out %s",
+	      sprintf(cmdbuf, "xwd -id %ld -out %s",
 		     ed->GetViewer()->GetCanvas()->window()->rep()->xwindow_,
 		     name);
 	      ed->GetWindow()->cursor(hourglass);
