@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1994 Vectaport Inc.
+ * Copyright (c) 1994,1999 Vectaport Inc.
  * Copyright (c) 1990, 1991 Stanford University
  *
  * Permission to use, copy, modify, distribute, and sell this software and
@@ -31,6 +31,7 @@
 #include <OverlayUnidraw/oved.h>
 #include <OverlayUnidraw/ovkit.h>
 #include <OverlayUnidraw/ovline.h>
+#include <OverlayUnidraw/ovmanips.h>
 #include <OverlayUnidraw/ovviews.h>
 #include <OverlayUnidraw/ovviewer.h>
 #include <OverlayUnidraw/paramlist.h>
@@ -39,7 +40,6 @@
 
 #include <Unidraw/clipboard.h>
 #include <Unidraw/editor.h>
-#include <Unidraw/manips.h>
 #include <Unidraw/selection.h>
 #include <Unidraw/statevars.h>
 
@@ -59,6 +59,8 @@
 
 #include <IV-2_6/_enter.h>
 
+#include <Attribute/attrlist.h>
+
 #include <math.h>
 #include <stream.h>
 
@@ -75,7 +77,10 @@ boolean LineOvComp::IsA (ClassId id) {
 }
 
 Component* LineOvComp::Copy () {
-    return new LineOvComp((Line*) GetGraphic()->Copy());
+    LineOvComp* comp =
+      new LineOvComp((Line*) GetGraphic()->Copy());
+    if (attrlist()) comp->SetAttributeList(new AttributeList(attrlist()));
+    return comp;
 }
 
 LineOvComp::LineOvComp (Line* graphic, OverlayComp* parent) 
@@ -187,15 +192,16 @@ Manipulator* LineOvView::CreateManipulator (
         v->Constrain(e.x, e.y);
         GetEndpoints(x0, y0, x1, y1);
 	rub = new SlidingLine(nil, nil, x0, y0, x1, y1, e.x, e.y);
-        m = new DragManip(
-	    v, rub, rel, tool, DragConstraint(HorizOrVert | Gravity)
+        m = new OpaqueDragManip(
+	    v, rub, rel, tool, DragConstraint(HorizOrVert | Gravity),
+	    GetGraphic()
 	);
 
     } else if (tool->IsA(SCALE_TOOL)) {
         v->Constrain(e.x, e.y);
         GetEndpoints(x0, y0, x1, y1);
         rub = new ScalingLine(nil, nil, x0, y0, x1, y1, (x0+x1)/2, (y0+y1)/2);
-        m = new DragManip(v, rub, rel, tool, Gravity);
+        m = new OpaqueDragManip(v, rub, rel, tool, Gravity, GetGraphic());
 
     } else if (tool->IsA(ROTATE_TOOL)) {
         v->Constrain(e.x, e.y);
@@ -203,7 +209,7 @@ Manipulator* LineOvView::CreateManipulator (
         rub = new RotatingLine(
             nil, nil, x0, y0, x1, y1, (x0+x1)/2, (y0+y1)/2, e.x, e.y
         );
-        m = new DragManip(v, rub, rel, tool, Gravity);
+        m = new OpaqueDragManip(v, rub, rel, tool, Gravity, GetGraphic());
 
     } else if (tool->IsA(RESHAPE_TOOL)) {
         v->Constrain(e.x, e.y);
@@ -405,7 +411,10 @@ boolean MultiLineOvComp::IsA (ClassId id) {
 }
 
 Component* MultiLineOvComp::Copy () {
-    return new MultiLineOvComp((SF_MultiLine*) GetGraphic()->Copy());
+    MultiLineOvComp* comp = 
+      new MultiLineOvComp((SF_MultiLine*) GetGraphic()->Copy());
+    if (attrlist()) comp->SetAttributeList(new AttributeList(attrlist()));
+    return comp;
 }
 
 MultiLineOvComp::MultiLineOvComp (SF_MultiLine* graphic, OverlayComp* parent) 
