@@ -26,8 +26,13 @@
  * Implementation of OverlayUnidraw class.
  */
 
+#include <OverlayUnidraw/ovcomps.h>
 #include <OverlayUnidraw/ovdoer.h>
+#include <OverlayUnidraw/oved.h>
+#include <OverlayUnidraw/ovpainter.h>
+#include <OverlayUnidraw/ovstates.h>
 #include <OverlayUnidraw/ovunidraw.h>
+#include <OverlayUnidraw/ovviewer.h>
 
 #include <Unidraw/Commands/dirty.h>
 #include <Unidraw/Commands/macro.h>
@@ -38,12 +43,18 @@
 #include <Unidraw/globals.h>
 #include <Unidraw/iterator.h>
 #include <Unidraw/ulist.h>
+#include <Unidraw/Graphic/graphic.h>
 
 #include <InterViews/display.h>
 #include <InterViews/event.h>
 #include <InterViews/resource.h>
 #include <InterViews/session.h>
+#include <InterViews/window.h>
 #include <IV-2_6/InterViews/world.h>
+#include <IV-X11/xevent.h>
+#include <IV-X11/xwindow.h>
+
+#include <iostream.h>
 
 /*****************************************************************************/
 
@@ -51,16 +62,22 @@ OverlayUnidraw::OverlayUnidraw (Catalog* c, int& argc, char** argv,
 				OptionDesc* od, PropertyData* pd) 
 : Unidraw(c, argc, argv, od, pd) {
     _cmdq = new MacroCmd();
+    _ovviewer = nil;
+
+    /* replace default Painter with an OverlayPainter */
+    OverlayGraphic::new_painter();
 }
 
 OverlayUnidraw::OverlayUnidraw (Catalog* c, World* w) 
 : Unidraw(c, w) {
     _cmdq = new MacroCmd();
+    _ovviewer = nil;
 }
 
 OverlayUnidraw::~OverlayUnidraw () 
 {
     delete _cmdq;
+    OverlayPainter::FreeCache();
 }
 
 void OverlayUnidraw::Append(Command* cmd) {
@@ -133,3 +150,44 @@ void OverlayUnidraw::Log (Command* cmd, boolean dirty) {
     }
 }
 
+/* static */ void OverlayUnidraw::pointer_tracker_func(Event& e) {
+  if (e.type() != Event::motion || !e.window()) return;
+  PixelCoord x = e.rep()->xevent_.xmotion.x;
+  PixelCoord y = e.rep()->xevent_.xmotion.y;
+  WindowRep& ewr = *e.window()->rep();
+  Iterator i;
+  for (unidraw->First(i); !unidraw->Done(i); unidraw->Next(i)) {
+    OverlayEditor* ed = (OverlayEditor*) unidraw->GetEditor(i);
+    Viewer* v; if (!(v = ed->GetViewer())) continue;
+    Canvas* c; if (!(c = v->GetCanvas())) continue;
+    Window* cw; if (!(cw = c->window())) continue;
+
+    /* if event is associated with the ApplicationWindow */
+    if (ed->GetWindow() == e.window()) {
+
+      /* adjust for delta between application window and Unidraw canvas */
+      PixelCoord deltax, deltay;
+      WindowRep& cwr = *cw->rep();
+      if (cwr.xpos_) // this test requires a window setup where xpos_ is zero after Window::bind
+      {
+	deltax = cwr.xpos_ - ewr.xpos_;
+	deltay = cwr.ypos_ - ewr.ypos_;
+      } else {
+	cw->offset_from_toplevel(deltax, deltay);
+      }
+      x -= deltax;
+      y -= deltay;
+      ed->ptrlocstate()->ptrcoords(x, cwr.canvas_->pheight() - y - 1);
+      break;
+    }
+
+    /* else if event is associated with the Unidraw canvas */
+    else if (cw == e.window()) {
+
+      /* coordinates will already be in the canvas coordinate system */
+      ed->ptrlocstate()->ptrcoords(x, ewr.canvas_->pheight() - y - 1);
+      break;
+
+    }
+  }
+}
