@@ -177,8 +177,8 @@ GraphicComp* IdrawCatalog::ReadPostScript (istream& in) {
     in >> _buf >> _psversion;
 
     if (_psversion > PSV_LATEST) {
-        fprintf(stderr, "warning: drawing version %d ", _psversion);
-        fprintf(stderr, "newer than idraw version %d\n", PSV_LATEST);
+        fprintf(stderr, "warning: drawing version %f ", _psversion);
+        fprintf(stderr, "newer than idraw version %f\n", PSV_LATEST);
     }
 
     float xincr, yincr;
@@ -442,7 +442,7 @@ void IdrawCatalog::PSReadBrush (istream& in, Graphic* gs) {
 	boolean undefined = false;
 	boolean none = false;
 	int p = 0;
-	int w = 0;
+	float w = 0;
 	int head = false;
 	int tail = false;
  
