@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1994-1995 Vectaport, Inc.
+ * Copyright (c) 1994-1999 Vectaport, Inc.
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided
@@ -34,6 +34,24 @@ static const char *const SERVER_HOST = ACE_DEFAULT_SERVER_HOST;
 #include <iostream.h>
 #include <string.h>
 
+#include <sys/stat.h>
+#include <unistd.h>
+
+#include <version.h>
+
+#if BUFSIZ>1024
+#undef BUFSIZ
+#define BUFSIZ 1024
+#endif
+
+#define GEOMOBJS_LINKING_TEST
+#if defined (GEOMOBJS_LINKING_TEST)
+#include <Unidraw/Graphic/geomobjs.h>
+#include <TopoFace/fgeomobjs.h>
+PointObj ip(0,0);
+FPointObj fp(0.,0.);
+#endif
+
 int main(int argc, char *argv[]) {
 
     boolean server_flag = argc>1 && strcmp(argv[1], "server") == 0;
@@ -67,7 +85,12 @@ int main(int argc, char *argv[]) {
     
 	// Start up one on stdin
 	ComterpHandler* stdin_handler = new ComterpHandler();
+#if 0
 	if (ACE::register_stdin_handler(stdin_handler, COMTERP_REACTOR::instance(), nil) == -1)
+#else
+	if (COMTERP_REACTOR::instance()->register_handler(0, stdin_handler, 
+							  ACE_Event_Handler::READ_MASK)==-1)
+#endif
 	    cerr << "comterp: unable to open stdin with ACE\n";
 
         // Perform logging service until COMTERP_QUIT_HANDLER receives SIGINT.
@@ -90,7 +113,7 @@ int main(int argc, char *argv[]) {
         ACE_ERROR_RETURN ((LM_ERROR, "%p\n", "open"), -1);
   
     FILE* fptr = fdopen(server.get_handle(), "r+");
-    char buffer[BUFSIZ];
+    char buffer[BUFSIZ*BUFSIZ];
 
     FILE* inptr = argc>=5 ? fopen(argv[4], "r") : stdin;
 
@@ -105,7 +128,7 @@ int main(int argc, char *argv[]) {
       istream in(&ibuf);
       
       for (;;) {
-	fgets(buffer, BUFSIZ, inptr);
+	fgets(buffer, BUFSIZ*BUFSIZ, inptr);
 	if (feof(inptr)) break;
 	out << buffer;
 	out.flush();
@@ -117,6 +140,8 @@ int main(int argc, char *argv[]) {
 	else {
 	  in.unget();
 	  in.gets(&inbuf);
+	  if (client_flag) 
+	    cout << inbuf << "\n";
 	}
       }
       
@@ -129,25 +154,32 @@ int main(int argc, char *argv[]) {
       filebuf obuf;
       obuf.attach(server.get_handle());
       ostream out(&obuf);
-      
+
+#if 0      
       for (;;) {
 	char ch;
 	in.get(ch);
 	if (!in.good()) break;
 	out << ch;
       }
+#else
+      char buffer[BUFSIZ*BUFSIZ];
+      while(!in.eof() && in.good()) {
+	in.read(buffer, BUFSIZ*BUFSIZ);
+	if (!in.eof() || in.gcount())
+	  out.write(buffer, in.gcount());
+      }
+#endif
       out.flush();
       
-      
-
 #if 0
       for (;;) {
-	fgets(buffer, BUFSIZ, inptr);
+	fgets(buffer, BUFSIZ*BUFSIZ, inptr);
 	if (feof(inptr)) break;
 	fputs(buffer, fptr);
 	fflush(fptr);
 #if 0
-	fgets(buffer, BUFSIZ, fptr);
+	fgets(buffer, BUFSIZ*BUFSIZ, fptr);
 	fputs(buffer, stdout);
 #else
 	char ch;
@@ -157,14 +189,14 @@ int main(int argc, char *argv[]) {
 	  if (ch != ' ') {
 	    ungetc(ch, fptr);
 	    ungetc('>', fptr);
-	    fgets(buffer, BUFSIZ, fptr);
+	    fgets(buffer, BUFSIZ*BUFSIZ, fptr);
 	    fputs(buffer, stdout);
 	  } else {
 	    printf( "> " );
 	  }
 	} else {
 	  ungetc(ch, fptr);
-	  fgets(buffer, BUFSIZ, fptr);
+	  fgets(buffer, BUFSIZ*BUFSIZ, fptr);
 	  fputs(buffer, stdout);
 	}
 #endif
@@ -184,8 +216,14 @@ int main(int argc, char *argv[]) {
 #endif
 
     if (server_flag || remote_flag) {
-      ComTerpServ* terp = new ComTerpServ();
+      ComTerpServ* terp = new ComTerpServ(BUFSIZ*BUFSIZ);
       terp->add_defaults();
+      struct stat buf;
+      int status = fstat(fileno(stdin), &buf);
+      if (S_ISREG(buf.st_mode) || S_ISFIFO(buf.st_mode))
+	terp->disable_prompt();
+      else
+	fprintf(stderr, "ivtools-%s comterp: type help for more info\n", VersionString);
       return terp->run();
     } else {
       ComTerp* terp = new ComTerp();
@@ -193,8 +231,26 @@ int main(int argc, char *argv[]) {
       if (run_flag && argc > 2 ) {
         const char *rfile = argv[2];
 	terp->runfile(rfile);
-      } else
+	return 0;
+      } else {
+	
+	struct stat buf;
+	int status = fstat(fileno(stdin), &buf);
+#if 0
+	fprintf(stderr,"S_ISLNK %d\n", S_ISLNK(buf.st_mode));
+	fprintf(stderr,"S_ISREG %d\n", S_ISREG(buf.st_mode));
+	fprintf(stderr,"S_ISDIR %d\n", S_ISDIR(buf.st_mode));
+	fprintf(stderr,"S_ISCHR %d\n", S_ISCHR(buf.st_mode));
+	fprintf(stderr,"S_ISBLK %d\n", S_ISBLK(buf.st_mode));
+	fprintf(stderr,"S_ISFIFO %d\n", S_ISFIFO(buf.st_mode));
+	fprintf(stderr,"S_ISSOCK %d\n", S_ISSOCK(buf.st_mode));
+#endif
+        if (S_ISREG(buf.st_mode) || S_ISFIFO(buf.st_mode))
+	  terp->disable_prompt();
+	else
+	  fprintf(stderr, "ivtools-%s comterp:  type help for more info\n", VersionString);
 	return terp->run();
+      }
     }
 
 }
