@@ -1,26 +1,26 @@
-/******************************************************************************/
-/* Copyright (c) 1994 Vectaport, Inc.                                  */
-/* Copyright (c) 1990, 1991 Stanford University                               */
-/*                                                                            */
-/* Permission to use, copy, modify, distribute, and sell this software and    */
-/* its documentation for any purpose is hereby granted without fee, provided  */
-/* that the above copyright notice appear in all copies and that both that    */
-/* copyright notice and this permission notice appear in supporting           */
-/* documentation, and that the names of the copyright holders not be used in  */
-/* advertising or publicity pertaining to distribution of the software        */
-/* without specific, written prior permission.  The copyright holders make    */
-/* no representations about the suitability of this software for any purpose. */
-/* It is provided "as is" without express or implied warranty.                */
-/*                                                                            */
-/* THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS          */
-/* SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. */
-/* IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,         */
-/* INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING      */
-/* FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,       */
-/* NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION       */
-/* WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.                              */
-/*                                                                            */
-/******************************************************************************/
+/*
+ * Copyright (c) 1994-1999 Vectaport, Inc.
+ * Copyright (c) 1990, 1991 Stanford University
+ *
+ * Permission to use, copy, modify, distribute, and sell this software and
+ * its documentation for any purpose is hereby granted without fee, provided
+ * that the above copyright notice appear in all copies and that both that
+ * copyright notice and this permission notice appear in supporting
+ * documentation, and that the names of the copyright holders not be used in
+ * advertising or publicity pertaining to distribution of the software
+ * without specific, written prior permission.  The copyright holders make
+ * no representations about the suitability of this software for any purpose.
+ * It is provided "as is" without express or implied warranty.
+ *
+ * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
+ * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
+ * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
+ * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+ * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+ * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ */
 
 /*
  * Graph editor main program.
@@ -37,16 +37,7 @@
 #include <stream.h>
 #include <string.h>
 #include <math.h>
-
-#if defined(__sun) && !defined(__svr4__)
-/* Disables atan2(0.0,0.0) warning messages */
-extern "C" {
-    int matherr(struct exception *x) {
-	if (x && strcmp(x->name, "atan2") == 0) return 1;
-	else return 0;
-    }
-}
-#endif
+#include <version.h>
 
 /*****************************************************************************/
 
@@ -150,6 +141,7 @@ static PropertyData properties[] = {
     { "*scribble_pointer", "false" },
     { "*slider_off",    "false"  },
     { "*zoomer_off",    "false"  },
+    { "*opaque_off",    "false"  },
     { "*help",          "false"  },
     { "*font",          "-adobe-helvetica-medium-r-normal--14-140-75-75-p-77-iso8859-1"  },
     { nil }
@@ -175,6 +167,8 @@ static OptionDesc options[] = {
     { "-soff", "*slider_off", OptionValueImplicit, "true" },
     { "-zoomer_off", "*zoomer_off", OptionValueImplicit, "true" },
     { "-zoff", "*zoomer_off", OptionValueImplicit, "true" },
+    { "-opaque_off", "*opaque_off", OptionValueImplicit, "true" },
+    { "-opoff", "*opaque_off", OptionValueImplicit, "true" },
     { "-help", "*help", OptionValueImplicit, "true" },
     { "-font", "*font", OptionValueNext },
     { nil }
@@ -182,24 +176,11 @@ static OptionDesc options[] = {
 
 
 static char* usage =
-"Usage: graphdraw \
-[any idraw parameter] \
-[-color5] \
-[-color6] \
-[-gray5] \
-\n\
-[-gray6] \
-[-gray7] \
-[-pagecols|-ncols] \
-[-pagerows|-nrows] \
-[-panner_off|-poff] \
-\n\
-[-panner_align|-pal tl|tc|tr|cl|c|cr|cl|bl|br|l|r|t|b|hc|vc ] \
-\n\
-[-scribble_pointer|-scrpt ] \
-[-slider_off|-soff] \
-[-zoomer_off|-zoff] \
-[file]";
+"Usage: graphdraw [any idraw parameter] [-color5] [-color6] \n\
+[-gray5] [-gray6] [-gray7] [-opaque_off|-opoff] [-pagecols|-ncols] \n\
+[-pagerows|-nrows] [-panner_off|-poff] \n\
+[-panner_align|-pal tl|tc|tr|cl|c|cr|cl|bl|br|l|r|t|b|hc|vc ] \n\
+[-scribble_pointer|-scrpt ] [-slider_off|-soff] [-zoomer_off|-zoff] [file]";
 
 /*****************************************************************************/
 
@@ -220,6 +201,8 @@ int main (int argc, char** argv) {
     GraphEditor* ed = new GraphEditor(initial_file);
     
     unidraw->Open(ed);
+    cerr << "ivtools-" << VersionString 
+	 << " graphdraw: see \"man graphdraw\" or type help here for command info\n";
     unidraw->Run();
 
     delete unidraw;
